"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runBabel = void 0;
const tslib_1 = require("tslib");
const error_1 = require("@dotcom-tool-kit/error");
const logger_1 = require("@dotcom-tool-kit/logger");
const babel = tslib_1.__importStar(require("@babel/core"));
const fast_glob_1 = tslib_1.__importDefault(require("fast-glob"));
const fs_1 = require("fs");
const path_1 = tslib_1.__importDefault(require("path"));
async function runBabel(logger, options, transformOptions) {
    const fileGlob = options.files ?? 'src/**/*.js';
    const files = await (0, fast_glob_1.default)(fileGlob);
    // Work out the root of the glob so we can strip this part of the path out of
    // the outputted files.
    // E.g., a glob of 'src/**/*.js'   = src/a/b.js -> lib/a/b.js
    //       a glob of 'src/a/**/*.js' = src/a/b.js -> lib/b.js
    const { base } = fast_glob_1.default.generateTasks(fileGlob)[0];
    const outputPath = options.outputPath ?? 'lib';
    if (options.configFile) {
        const { configFile } = options;
        transformOptions = transformOptions ? { ...transformOptions, configFile } : { configFile };
    }
    logger.info('running babel');
    const unhook = (0, logger_1.hookConsole)(logger, 'babel');
    await Promise.all(files.map(async (file) => {
        const transformed = await babel.transformFileAsync(file, transformOptions);
        if (!transformed?.code) {
            const error = new error_1.ToolKitError('Babel failed to generate code');
            error.details = `the problematic file was ${file}`;
            throw error;
        }
        // Create parent directories if they don't exist before creating child file of transpiled code.
        const filePath = path_1.default.join(outputPath, path_1.default.relative(base, file));
        await fs_1.promises.mkdir(path_1.default.dirname(filePath), { recursive: true });
        await fs_1.promises.writeFile(filePath, transformed.code);
    }));
    unhook();
}
exports.runBabel = runBabel;
